@@ -1,7 +1,7 @@
 /*
   This file is part of KAddressBook.
 
-  Copyright (c) 2009-2016 Laurent Montel <montel@kde.org>
+  Copyright (c) 2009-2017 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -39,7 +39,7 @@ KAddressBookPart::KAddressBookPart(QWidget *parentWidget, QObject *parent,
                                    const QVariantList &)
     : KParts::ReadOnlyPart(parent)
 {
-    setComponentName(QStringLiteral("kaddressbook"), QStringLiteral("kaddressbook"));
+    setComponentName(QStringLiteral("kaddressbook"), i18n("KAddressBook"));
     KAddressBookMigrateApplication migrate;
     migrate.migrate();
 
