@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2016 Laurent Montel <montel@kde.org>
+    Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -26,7 +26,7 @@ class AddressBookQuickWidget : public QQuickWidget
 {
     Q_OBJECT
 public:
-    explicit AddressBookQuickWidget(QWidget *parent = Q_NULLPTR);
+    explicit AddressBookQuickWidget(QWidget *parent = nullptr);
     ~AddressBookQuickWidget();
 
     void loadQmlFile(const QString &qmlFilePath);
