@@ -3,7 +3,7 @@
   Copyright (c) 1996-2002 Mirko Boehm <mirko@kde.org>
                           Tobias Koenig <tokoe@kde.org>
 
-  Copyright (c) 2009-2016 Laurent Montel <montel@kde.org>
+  Copyright (c) 2009-2017 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -71,7 +71,7 @@ public:
      */
     PrintingWizard(QPrinter *printer,
                    QItemSelectionModel *selectionModel,
-                   QWidget *parent = Q_NULLPTR);
+                   QWidget *parent = nullptr);
 
     /**
      * Destroys the printing wizard.
@@ -119,7 +119,7 @@ protected:
     class PrintStyleDefinition
     {
     public:
-        PrintStyleDefinition(PrintStyleFactory *factory = Q_NULLPTR, PrintStyle *style = Q_NULLPTR)
+        PrintStyleDefinition(PrintStyleFactory *factory = nullptr, PrintStyle *style = nullptr)
             : printstyleFactory(factory),
               printStyle(style)
         {
